summary.mid: Summarize MID Models

View source: R/summary_mid.R

summary.midR Documentation

Summarize MID Models

Description

For "mid" objects, an S3 method of summary() prints a comprehensive summary of a fitted MID model.

Usage

## S3 method for class 'mid'
summary(
  object,
  diagnosis = FALSE,
  digits = max(3L, getOption("digits") - 2L),
  ...
)

Arguments

object

a "mid" object to be summarized.

diagnosis

logical. If TRUE, the diagnosis plot is displayed. Defaults to FALSE.

digits

the number of significant digits for printing numeric values.

...

arguments to be passed to graphics::panel.smooth() for the diagnosis plot.

Details

The S3 method summary.mid() generates a comprehensive overview of the fitted MID model. The output includes:

  • Call: the function call used to fit the MID model.

  • Link: name of the link function used to fit the MID model, if applicable.

  • Uninterpreted Variation Ratio: proportion of target model variance not explained by MID model.

  • Residuals: five-number summary of (working) residuals.

  • Encoding: summary of encoding schemes per variable.

  • Diagnosis: residuals vs fitted values plot (displayed only when diagnosis = TRUE).

Value

summary.mid() returns the original "mid" object invisibly.

See Also

interpret, print.mid

Examples

# Summarize a fitted MID model
data(cars, package = "datasets")
mid <- interpret(dist ~ speed, cars)
summary(mid)

midr documentation built on Jan. 16, 2026, 5:06 p.m.