mid.extract() returns the component extracted from the object,
mid.encoding.scheme() returns a data frame containing the information about encoding schemes,
mid.frames() returns a list of the encoding frames,
mid.terms() returns a character vector of the term labels, and
Arguments
object
a "mid" object.
component
a literal character string or name. The name of the component to extract, such as "frames", "encoding.scheme" and "terms".
...
optional parameters to be passed to the function used to extract the component.
main.effect
logical. If FALSE, the main effect terms are excluded.
interaction
logical. If FALSE, the interaction terms are excluded.
require
a character vector of variable names. The terms that are not related to any of the specified names are excluded.
remove
a character vector of variable names. The terms that are related to at least one of the specified names are excluded.