mid.importance() returns an object of the class "mid.importance" containing the following components.
importance
the data frame of calculated importances.
predictions
the matrix of the fitted or predicted MID values.
measure
the type of the importance measure.
Arguments
object
a "mid" object.
data
a data frame containing the observations to be used to calculate the MID importance. If NULL, the fitted.matrix of the MID model is used.
weights
an optional numeric vector of sample weights.
sort
logical. If TRUE, the output data frame is sorted by MID importance.
measure
an integer specifying the measure of the MID importance. Possible alternatives are 1 for the mean absolute effect, 2 for the root mean square effect, and 3 for the median absolute effect.
x
a "mid.importance" object to be printed.
digits
an integer specifying the minimum number of significant digits to be printed.
...
additional parameters to be passed to print.data.frame() to print the importance of component functions.
Details
mid.importance() returns an object of class "mid.importance".
The MID importance is defined for each component function of a MID model as the mean absolute effect in the given data.