| summary.mid | R Documentation |
For "mid" objects, an S3 method of summary() prints a comprehensive summary of a fitted MID model.
## S3 method for class 'mid'
summary(
object,
diagnosis = FALSE,
digits = max(3L, getOption("digits") - 2L),
...
)
object |
a "mid" object to be summarized. |
diagnosis |
logical. If |
digits |
the number of significant digits for printing numeric values. |
... |
arguments to be passed to |
The S3 method summary.mid() generates a comprehensive overview of the fitted MID model.
The output includes:
Call: the function call used to fit the MID model.
Link: name of the link function used to fit the MID model, if applicable.
Uninterpreted Variation Ratio: proportion of target model variance not explained by MID model.
Residuals: five-number summary of (working) residuals.
Encoding: summary of encoding schemes per variable.
Diagnosis: residuals vs fitted values plot (displayed only when diagnosis = TRUE).
summary.mid() returns the original "mid" object invisibly.
interpret, print.mid
# Summarize a fitted MID model
data(cars, package = "datasets")
mid <- interpret(dist ~ speed, cars)
summary(mid)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.