summary.mid() returns the "mid" object passed to the function without any modification.
Arguments
object
a "mid" object to be summarized.
digits
an integer specifying the number of significant digits.
top.n
an integer specifying the maximum number of terms to be printed with the MID importance values.
...
not used.
Details
The S3 method of summary() for "mid" objects prints basic information about the MID model including the uninterpreted variation ratio, residuals, encoding schemes, and MID importance.